@@ -3,7 +3,7 @@ mod parameter;
 mod smooth;
 mod time;
 
-pub mod atomic_float;
+pub mod atomic;
 pub mod block_buffer;
 pub mod decibel;
 pub mod pcm;
