@@ -10,7 +10,7 @@ use std::fmt;
 use std::ops;
 use std::slice;
 
-use super::{ProcFrames, SampleRate, Seconds};
+use super::{SampleRate, Seconds};
 
 const SETTLE: f32 = 0.00001f32;
 
@@ -121,12 +121,12 @@ impl<const MAX_BLOCKSIZE: usize> SmoothF32<MAX_BLOCKSIZE> {
         self.status
     }
 
-    pub fn process(&mut self, proc_frames: ProcFrames<MAX_BLOCKSIZE>) {
+    pub fn process(&mut self, frames: usize) {
         if self.status != SmoothStatus::Active {
             return;
         }
 
-        let frames = proc_frames.unchecked_frames();
+        let frames = frames.min(MAX_BLOCKSIZE);
         let input = self.input * self.a;
 
         self.output[0] = input + (self.last_output * self.b);
@@ -278,12 +278,12 @@ impl<const MAX_BLOCKSIZE: usize> SmoothF64<MAX_BLOCKSIZE> {
         self.status
     }
 
-    pub fn process(&mut self, proc_frames: ProcFrames<MAX_BLOCKSIZE>) {
+    pub fn process(&mut self, frames: usize) {
         if self.status != SmoothStatus::Active {
             return;
         }
 
-        let frames = proc_frames.unchecked_frames();
+        let frames = frames.min(MAX_BLOCKSIZE);
         let input = self.input * self.a;
 
         self.output[0] = input + (self.last_output * self.b);
